drain-swamp
==============

Python build backend with build plugins and dependency lock switch

|feature banner|

.. PYVERSIONS

\* Python 3.9 through 3.13, PyPy

**New in 1.3.x**

post process .lock files paths relative;

**New in 1.2.x**

generate version file if missing; ci workflows recreate generated files;
docs use available version str; badges; cease ignoring version file;

.. |feature banner| image:: _static/drain-swamp-banner-640-320.*
   :alt: drain-swamp features build plugins and dependency lock switch
